Changes
=======

0.7
---

* Dropped support for Python 3.

0.6
---

* First official release PyPI.

0.5
---

* Fixed compatibility with Debian patched libtidy5deb1.

0.4
---

* Compatibility with html-tidy 5.6.0.
* Added support for Python 3.

0.3
---

* Initial release under new maintainer.
* Incorporated Debian patches.
* Various compatiblity fixes (eg. with 64-bit machines).
* Various code cleanups.
* New test suite.
* New documentation.
* Support for new HTML 5 tidy library.
